diff --git a/composer.json b/composer.json
index af4eaee..dabc62f 100644
--- a/composer.json
+++ b/composer.json
@@ -15,12 +15,13 @@
"intervention/image": "^3.10",
"joshbrw/laravel-module-installer": "^2.0",
"laravel/framework": "^12.0",
+ "jackiedo/log-reader": "^2.4",
"laravel/pulse": "^1.2",
"laravel/tinker": "^2.9",
"maatwebsite/excel": "^3.1",
"nwidart/laravel-modules": "^11.0",
"opcodesio/log-viewer": "^3.10",
- "rasyahroel/itsecurity": "dev-main",
+ "rasyahroel/itsecurity-module": "dev-main",
"rasyahroel/usermanagement-module": "dev-master",
"spatie/laravel-activitylog": "^4.8",
"spatie/laravel-pdf": "^1.5",
@@ -41,7 +42,10 @@
"App\\": "app/",
"Database\\Factories\\": "database/factories/",
"Database\\Seeders\\": "database/seeders/"
- }
+ },
+ "files": [
+ "app/Helpers/helpers.php"
+ ]
},
"autoload-dev": {
"psr-4": {
@@ -106,9 +110,14 @@
"url": "https://git.putrakuningan.com/daengdeni/authentication"
},
{
- "name": "rasyahroel/itsecurity",
+ "name": "rasyahroel/itsecurity-module",
"type": "vcs",
"url": "https://git.putrakuningan.com/rasyahroel/itsecurity"
+ },
+ {
+ "name": "jackiedo/log-reader",
+ "type": "vcs",
+ "url": "https://github.com/daengdeni/Laravel-Log-Reader.git"
}
]
}
diff --git a/resources/views/welcome.blade.php b/resources/views/welcome.blade.php
index cae76d4..c3f5455 100644
--- a/resources/views/welcome.blade.php
+++ b/resources/views/welcome.blade.php
@@ -50,75 +50,17 @@
-
- {{-- Report History User --}}
-
-
-
-
+ {{-- Report History User --}}
+
+
+
-
-
- {{-- Audit Rail --}}
-
diff --git a/app/Helpers/helpers.php b/app/Helpers/helpers.php
index ef95f70..e647294 100644
--- a/app/Helpers/helpers.php
+++ b/app/Helpers/helpers.php
@@ -1,22 +1,35 @@
locale($locale);
+use Carbon\Carbon;
- // Tentukan format berdasarkan parameter
- if ($showDay && $time) {
- return $carbon->isoFormat('dddd, LL HH:mm:ss');
- } elseif ($showDay) {
- return $carbon->isoFormat('dddd, LL');
- } elseif ($time) {
- return $carbon->isoFormat('LL HH:mm:ss');
- } else {
- return $carbon->isoFormat('LL');
- }
+if (!function_exists('formatTanggalWaktu')) {
+ function formatTanggalWaktu($tanggal, $time = false, $showDay = false, $locale = 'id_ID')
+ {
+ // Parse tanggal dan waktu
+ $datetime = $time ? $tanggal . ' ' . $time : $tanggal;
+ $carbon = Carbon::parse($datetime)->locale($locale);
+
+ // Tentukan format berdasarkan parameter
+ if ($showDay && $time) {
+ return $carbon->isoFormat('dddd, LL HH:mm:ss');
+ } elseif ($showDay) {
+ return $carbon->isoFormat('dddd, LL');
+ } elseif ($time) {
+ return $carbon->isoFormat('LL HH:mm:ss');
+ } else {
+ return $carbon->isoFormat('LL');
}
}
+}
+
+function formatNotifikasi($notifikasi)
+{
+ $data = json_decode(json_encode($notifikasi->data));
+ $message = $data->message;
+ $data = $data->data;
+ $notifikasi = [
+ 'title' => $message->title,
+ 'message' => $message->message,
+ ];
+ return $notifikasi;
+}